@@ -20,6 +20,7 @@ from typing import (
     Generic,
     Iterable,
     Iterator,
+    NamedTuple,
     Optional,
     TypeVar,
     Union,
@@ -83,6 +84,23 @@ ScreenResultCallbackType = Union[
 """Type of a screen result callback function."""
 
 
+class HoverWidgets(NamedTuple):
+    """Result of [get_hover_widget_at][textual.screen.Screen.get_hover_widget_at]"""
+
+    mouse_over: tuple[Widget, Region]
+    """Widget and region directly under the mouse."""
+    hover_over: tuple[Widget, Region] | None
+    """Widget with a hover style under the mouse, or `None` for no hover style widget."""
+
+    @property
+    def widgets(self) -> tuple[Widget, Widget | None]:
+        """Just the widgets."""
+        return (
+            self.mouse_over[0],
+            None if self.hover_over is None else self.hover_over[0],
+        )
+
+
 @rich.repr.auto
 class ResultCallback(Generic[ScreenResultType]):
     """Holds the details of a callback."""
@@ -341,6 +359,11 @@ class Screen(Generic[ScreenResultType], Widget):
             extras.append("_tooltips")
         return (*super().layers, *extras)
 
+    @property
+    def size(self) -> Size:
+        """The size of the screen."""
+        return self.app.size - self.styles.gutter.totals
+
     def _watch_focused(self):
         self.refresh_bindings()
 
@@ -463,7 +486,7 @@ class Screen(Generic[ScreenResultType], Widget):
 
         return bindings_map
 
-    def _arrange(self, size: Size) -> DockArrangeResult:
+    def arrange(self, size: Size) -> DockArrangeResult:
         """Arrange children.
 
         Args:
@@ -512,7 +535,7 @@ class Screen(Generic[ScreenResultType], Widget):
                 else self._nodes
             ),
             size,
-            self.screen.size,
+            self.size,
             False,
         )
 
@@ -579,6 +602,33 @@ class Screen(Generic[ScreenResultType], Widget):
         """
         return self._compositor.get_widget_at(x, y)
 
+    def get_hover_widgets_at(self, x: int, y: int) -> HoverWidgets:
+        """Get the widget, and its region directly under the mouse, and the first
+        widget, region pair with a hover style.
+
+        Args:
+            x: X Coordinate.
+            y: Y Coordinate.
+
+        Returns:
+            A pair of (WIDGET, REGION) tuples for the top most and first hover style respectively.
+
+        Raises:
+            NoWidget: If there is no widget under the screen coordinate.
+
+        """
+        widgets_under_coordinate = iter(self._compositor.get_widgets_at(x, y))
+        try:
+            top_widget, top_region = next(widgets_under_coordinate)
+        except StopIteration:
+            raise errors.NoWidget(f"No hover widget under screen coordinate ({x}, {y})")
+        if not top_widget._has_hover_style:
+            for widget, region in widgets_under_coordinate:
+                if widget._has_hover_style:
+                    return HoverWidgets((top_widget, top_region), (widget, region))
+            return HoverWidgets((top_widget, top_region), None)
+        return HoverWidgets((top_widget, top_region), (top_widget, top_region))
+
     def get_widgets_at(self, x: int, y: int) -> Iterable[tuple[Widget, Region]]:
         """Get all widgets under a given coordinate.
 
@@ -1375,7 +1425,7 @@ class Screen(Generic[ScreenResultType], Widget):
         """Screen has suspended."""
         if self.app.SUSPENDED_SCREEN_CLASS:
             self.add_class(self.app.SUSPENDED_SCREEN_CLASS)
-        self.app._set_mouse_over(None)
+        self.app._set_mouse_over(None, None)
         self._clear_tooltip()
         self.stack_updates += 1
 
@@ -1487,14 +1537,17 @@ class Screen(Generic[ScreenResultType], Widget):
                 tooltip.update(tooltip_content)
 
     def _handle_mouse_move(self, event: events.MouseMove) -> None:
+        hover_widget: Widget | None = None
         try:
             if self.app.mouse_captured:
                 widget = self.app.mouse_captured
                 region = self.find_widget(widget).region
             else:
-                widget, region = self.get_widget_at(event.x, event.y)
+                (widget, region), hover = self.get_hover_widgets_at(event.x, event.y)
+                if hover is not None:
+                    hover_widget = hover[0]
         except errors.NoWidget:
-            self.app._set_mouse_over(None)
+            self.app._set_mouse_over(None, None)
             if self._tooltip_timer is not None:
                 self._tooltip_timer.stop()
             if not self.app._disable_tooltips:
@@ -1502,9 +1555,8 @@ class Screen(Generic[ScreenResultType], Widget):
                     self.get_child_by_type(Tooltip).display = False
                 except NoMatches:
                     pass
-
         else:
-            self.app._set_mouse_over(widget)
+            self.app._set_mouse_over(widget, hover_widget)
             widget.hover_style = event.style
             if widget is self:
                 self.post_message(event)
